@@ -1,21 +1,7 @@
 /*
- * Copyright (C) 2014-2015 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014-2015 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #ifndef DEVICEINTERFACE_H
@@ -23,16 +9,17 @@
 
 #include "object.h"
 
-#include <QStringList>
 #include <QDBusAbstractAdaptor>
+#include <QStringList>
 
 class QDBusMessage;
 class QDBusObjectPath;
+class MediaTransportInterface;
 
 class DeviceObject : public QObject
 {
 public:
-    explicit DeviceObject(const QDBusObjectPath &path, QObject *parent = Q_NULLPTR);
+    explicit DeviceObject(const QDBusObjectPath &path, QObject *parent = nullptr);
 };
 
 class DeviceInterface : public QDBusAbstractAdaptor, public Object
@@ -56,7 +43,7 @@ class DeviceInterface : public QDBusAbstractAdaptor, public Object
     Q_PROPERTY(QString Modalias READ modalias)
 
 public:
-    explicit DeviceInterface(const QDBusObjectPath &path, const QVariantMap &properties, QObject *parent = Q_NULLPTR);
+    explicit DeviceInterface(const QDBusObjectPath &path, const QVariantMap &properties, QObject *parent = nullptr);
 
     QString address() const;
 
@@ -91,6 +78,8 @@ public:
 
     QString modalias() const;
 
+    MediaTransportInterface *mediaTransport() const;
+
 public Q_SLOTS:
     void Connect();
     void Disconnect();
@@ -102,9 +91,14 @@ public Q_SLOTS:
 private:
     void connectMediaPlayer();
     void disconnectMediaPlayer();
+    void connectMediaTransport();
+    void disconnectMediaTransport();
 
     QStringList m_connectedUuids;
-    Object *m_mediaPlayer;
+    Object *m_mediaPlayer = nullptr;
+    MediaTransportInterface *m_mediaTransport = nullptr;
+
+    friend class DeviceManager;
 };
 
 #endif // DEVICEINTERFACE_H
